@@ -3,10 +3,12 @@
 from wish_command_execution.backend.base import Backend
 from wish_command_execution.backend.bash import BashBackend
 from wish_command_execution.backend.factory import BashConfig, SliverConfig, create_backend
+from wish_command_execution.backend.sliver import SliverBackend
 
 __all__ = [
     "Backend",
     "BashBackend",
+    "SliverBackend",
     "BashConfig",
     "SliverConfig",
     "create_backend",
